"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiLambdaApp = void 0;
const ApiApp_1 = require("./ApiApp");
const ApiRequest_1 = require("./model/ApiRequest");
const timed_1 = require("./util/timed");
/**
 * Impementation of the `ApiApp` class that handles native
 * AWS Lambda requests and can be used to provide a Lambda
 * function handler.
 *
 * The `run` method is the function handler entrypoint.
 */
class ApiLambdaApp extends ApiApp_1.ApiApp {
    /**
     * Create a new lambda app.
     *
     * @param controllersPath (Optional) Paths to the directories that contain controller `js` files.
     *                        Required if the default `Container` is used, or the provided
     *                        `Container` instance has its `autoBindInjectable` flag set to `true`.
     *                        Ignored if the provided `Container` instance has its `autoBindInjectable`
     *                        flag set to `false`.
     * @param appConfig (Optional) Application config to pass to `lambda-api`.
     * @param appContainer (Optional) `InversifyJS` IOC `Container` instance which can build
     *                     controllers and error interceptors.
     */
    constructor(controllersPath, appConfig, appContainer) {
        super(controllersPath, appConfig, appContainer);
        this.logger = this.logFactory.getLogger(ApiLambdaApp);
    }
    /**
     * Process the passed lambda event and context as a synchronous HTTP request.
     *
     * @param request API Gateway or ALB request.
     * @param context Request context.
     * @returns The response.
     */
    async run(event, context) {
        this.logger.info("Received event, initialising controllers and processing event");
        await super.initialiseControllers();
        return await this.apiServer.processEvent(event, context);
    }
}
__decorate([
    timed_1.timed,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [ApiRequest_1.ApiRequest, Object]),
    __metadata("design:returntype", Promise)
], ApiLambdaApp.prototype, "run", null);
exports.ApiLambdaApp = ApiLambdaApp;
//# sourceMappingURL=ApiLambdaApp.js.map