"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.timed = void 0;
const marky_1 = require("marky");
const Environment_1 = require("./Environment");
/**
 * Decorator that can be applied to a method or function to
 * profile it's execution time in milliseconds. Timing info
 * is output to the console.
 *
 * The environment variable `PROFILE_API` must be set to `1` for
 * profiling information to be recorded and output.
 */
function timed(_, propertyKey, descriptor) {
    let functionToMeasure = descriptor.value;
    descriptor.value = async function (...args) {
        if (Environment_1.ProfilingEnabled) {
            marky_1.mark(propertyKey);
        }
        let result = await functionToMeasure.apply(this, args);
        if (Environment_1.ProfilingEnabled) {
            let measurement = marky_1.stop(propertyKey);
            console.log(`method '${measurement.name}' took ${measurement.duration.toFixed(2)} ms`);
        }
        return result;
    };
}
exports.timed = timed;
//# sourceMappingURL=timed.js.map